This directory subtree contains Annalist data that describes bibliographic records, largeely in the style of BibJSON.

NOTE: do not delete _annalist_site/site_meta.jsonld from the target site when updating site data:  that file is site-specific.
